package com.mortals.xhx.module.model.service.impl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.util.DataUtil;
import com.mortals.framework.util.StringUtils;
import com.mortals.xhx.common.code.ModelCensusStatus;
import com.mortals.xhx.common.code.ModelCensusType;
import com.mortals.xhx.module.model.model.ModelCensusQuery;
import com.mortals.xhx.module.model.model.ModelEntity;
import com.mortals.xhx.module.model.model.ModelQuery;
import com.mortals.xhx.module.model.service.ModelService;
import com.mortals.xhx.module.site.model.SiteEntity;
import com.mortals.xhx.module.site.service.SiteService;
import io.sentry.protocol.App;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.xhx.module.model.dao.ModelCensusDao;
import com.mortals.xhx.module.model.model.ModelCensusEntity;
import com.mortals.xhx.module.model.service.ModelCensusService;

import java.util.*;
import java.util.stream.Collectors;

/**
* ModelCensusService
* 模块下的数据统计 service实现
*
* @author zxfei
* @date 2022-07-05
*/
@Service("modelCensusService")
public class ModelCensusServiceImpl extends AbstractCRUDServiceImpl<ModelCensusDao, ModelCensusEntity, Long> implements ModelCensusService {
    @Autowired
    private SiteService siteService;
    @Autowired
    private ModelService modelService;

    @Override
    protected void findAfter(ModelCensusEntity entity, Context context, List<ModelCensusEntity> list) throws AppException {
        setInfo(list);
    }

    @Override
    public List<ModelCensusEntity> getModelCensusList(Long modelId) {
        Map<String, Object> condition = new HashMap<>();
        condition.put("modelId",modelId);
        List<ModelCensusEntity> list = this.dao.getList(condition);
        setInfo(list);
        return list;
    }

    @Override
    public List<ModelCensusEntity> getListBySiteId(Long siteId) throws AppException {
        if(siteId==null || siteId==0){
            return Collections.emptyList();
        }
        SiteEntity siteEntity = siteService.get(siteId);
        if(siteEntity!=null){
            List<String> modelIds = StringUtils.converStr2List(siteEntity.getModelIds());
            List<Long> ids = modelIds.stream().map(s -> DataUtil.converStr2Long(s.trim(),0)).collect(Collectors.toList());
            if(ids.isEmpty()){
                ids.add(0l);
            }
            ModelCensusQuery censusQuery = new ModelCensusQuery();
            censusQuery.setModelIdList(ids);
            List<ModelCensusEntity> modelCensusEntityList = this.find(censusQuery);
            return modelCensusEntityList;
        }else {
            return Collections.emptyList();
        }
    }

    @Override
    protected void validData(ModelCensusEntity entity, Context context) throws AppException {
        if(entity.getModelId()==null){
            throw new AppException("模块ID不能为空");
        }
        if(StringUtils.isEmpty(entity.getCensusName())){
            throw new AppException("数据统计名称不能为空");
        }
        if(entity.getStatus()==null){
            throw new AppException("开通状态不能为空");
        }
        if(entity.getCensusType()==null){
            throw new AppException("所属类型不能为空");
        }
    }

    private void setInfo(List<ModelCensusEntity> list){
        if(CollectionUtils.isNotEmpty(list)) {
            list.stream().forEach(item -> {
                ModelCensusStatus status = ModelCensusStatus.getByValue(item.getStatus());
                item.setStatusName(status != null ? status.getDesc() : "");
                ModelCensusType type = ModelCensusType.getByValue(item.getCensusType());
                item.setCensusTypeName(type != null ? type.getDesc() : "");
            });
        }
    }
}