package com.mortals.xhx.module.model.service.impl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.util.DataUtil;
import com.mortals.framework.util.StringUtils;
import com.mortals.xhx.module.model.model.ModelCensusEntity;
import com.mortals.xhx.module.model.model.ModelQuery;
import com.mortals.xhx.module.model.service.ModelCensusService;
import com.mortals.xhx.module.site.model.SiteEntity;
import com.mortals.xhx.module.site.service.SiteService;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.xhx.module.model.dao.ModelDao;
import com.mortals.xhx.module.model.model.ModelEntity;
import com.mortals.xhx.module.model.service.ModelService;

import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

/**
* ModelService
* 模块 service实现
*
* @author zxfei
* @date 2022-01-12
*/
@Service("modelService")
public class ModelServiceImpl extends AbstractCRUDServiceImpl<ModelDao, ModelEntity, Long> implements ModelService {

    @Autowired
    private ModelCensusService modelCensusService;
    @Autowired
    private SiteService siteService;

    @Override
    public List<ModelEntity> getListAllInfo(ModelQuery params, Context context) throws AppException {
        List<ModelEntity> list = this.dao.getList(params);
        if(CollectionUtils.isNotEmpty(list)){
            list.stream().forEach(item->{
                List<ModelCensusEntity> censusList = modelCensusService.getModelCensusList(item.getId());
                item.setCensusList(censusList);
            });
        }
        return list;
    }

    @Override
    public List<ModelEntity> getListBySiteId(Long siteId) throws AppException {
        if(siteId==null || siteId==0){
            return Collections.emptyList();
        }
        SiteEntity siteEntity = siteService.get(siteId);
        if(siteEntity!=null){
            List<String> modelIds = StringUtils.converStr2List(siteEntity.getModelIds());
            List<Long> ids = modelIds.stream().map(s -> DataUtil.converStr2Long(s.trim(),0)).collect(Collectors.toList());
            if(ids.isEmpty()){
                ids.add(0l);
            }
            ModelQuery modelQuery = new ModelQuery();
            modelQuery.setIdList(ids);
            List<ModelEntity> modelEntityList = this.find(modelQuery);
            return modelEntityList;
        }else {
            return Collections.emptyList();
        }
    }
}