package com.mortals.xhx.module.model.web;

import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.common.Rest;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.model.OrderCol;
import com.mortals.framework.model.PageInfo;
import com.mortals.framework.model.Result;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.framework.web.BasePhpCRUDJsonMappingController;
import com.mortals.xhx.base.system.param.service.ParamService;
import com.mortals.xhx.module.model.model.ModelEntity;
import com.mortals.xhx.module.model.model.ModelQuery;
import com.mortals.xhx.module.model.service.ModelService;
import com.mortals.xhx.module.window.model.WindowMatterEntity;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 模块
 *
 * @author zxfei
 * @date 2022-01-20
 */
@RestController
@RequestMapping("model")
public class ModelController extends BaseCRUDJsonBodyMappingController<ModelService, ModelEntity, Long> {

    @Autowired
    private ParamService paramService;

    public ModelController() {
        super.setFormClass(ModelForm.class);
        super.setModuleDesc("模块");
    }


    @Override
    protected void doListBefore(ModelEntity query, Map<String, Object> model, Context context) throws AppException {
        query.setOrderColList(new ArrayList<OrderCol>() {
            {
                add(new OrderCol("a.sort", OrderCol.ASCENDING));
            }
        });
        super.doListBefore(query, model, context);
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
        super.init(model, context);
    }

    /**
     * 条件查询，无分页信息
     * @param query
     * @return
     */
    @PostMapping({"list/noPage"})
    @UnAuth
    public Rest<Object> getList(@RequestBody ModelQuery query) {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "查询" + this.getModuleDesc();
        int code=1;
        try {
            List<ModelEntity> result = this.getService().find(query, context);
            model.put("data", result);
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }

        this.init(model, context);
        ret.setCode(code);
        ret.setData(model);
        ret.setDict(model.remove("dict"));
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

    /***
     * 包含模块下的数据统计
     * @param query
     * @return
     */
    @PostMapping({"list/allInfo"})
    @UnAuth
    public Rest<Object> getListAllInfo(@RequestBody ModelQuery query) {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "查询" + this.getModuleDesc();
        int code=1;
        try {
            List<ModelEntity> result = this.getService().getListAllInfo(query, context);
            model.put("data", result);
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }

        this.init(model, context);
        ret.setCode(code);
        ret.setData(model);
        ret.setDict(model.remove("dict"));
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

    /**
     * 通过站点查询
     * @param query
     * @return
     */
    @PostMapping({"list/bySite"})
    @UnAuth
    public Rest<Object> getListBySite(@RequestBody ModelEntity query) {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "查询" + this.getModuleDesc();
        int code=1;
        try {
            List<ModelEntity> result = this.getService().getListBySiteId(query.getSiteId());
            model.put("data", result);
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }

        this.init(model, context);
        ret.setCode(code);
        ret.setData(model);
        ret.setDict(model.remove("dict"));
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }
}