package com.mortals.xhx.feign.model;

import com.alibaba.fastjson.JSON;
import com.mortals.xhx.common.code.ApiRespCodeEnum;
import com.mortals.xhx.common.pdu.ModelPdu;
import com.mortals.xhx.common.pdu.SitePdu;
import com.mortals.xhx.feign.IFeign;
import com.mortals.xhx.feign.model.vo.ModelCensusFeignVO;
import com.mortals.xhx.feign.model.vo.ModelFeignVO;
import com.mortals.xhx.feign.model.vo.SiteFeignVO;
import com.mortals.xhx.feign.rsp.ApiResp;
import feign.hystrix.FallbackFactory;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

import java.util.List;

@FeignClient(name = "base-manager", path = "/zwfw", fallback = ModelFeignFallbackFactory.class)
public interface IApiModelFeign extends IFeign {

    /**
     * 根据条件查询站点列表
     * @param query
     * @return
     */
    @PostMapping(value = "/site/list/noPage")
    String getSitesByQuery(@RequestBody SitePdu query);

    /**
     * 根据条件查询站点列表
     * @param query
     * @return
     */
    @PostMapping(value = "/site/list/allInfo")
    ApiResp<List<SiteFeignVO>> getSitesAllInfoByQuery(@RequestBody SitePdu query);

    /***
     * 站点模块列表
     * @param query
     * @return
     */
    @PostMapping(value = "model/list/noPage")
    ApiResp<List<ModelFeignVO>> getModelByQuery(@RequestBody ModelPdu query);

    /***
     * 站点模块列表
     * @param query
     * @return
     */
    @PostMapping(value = "model/list/bySite")
    ApiResp<List<ModelFeignVO>> getModelBySiteId(@RequestBody ModelPdu query);

    /***
     * 站点模块列表
     * @param query
     * @return
     */
    @PostMapping(value = "model/list/allInfo")
    String getModelallInfo(@RequestBody ModelPdu query);

    /***
     * 站点模块数据统计列表
     * @return
     */
    @PostMapping(value = "model/census/list/noPage")
    ApiResp<List<ModelCensusFeignVO>> getModelCensusByQuery(@RequestBody ModelPdu query);

    @PostMapping(value = "model/census/list/bySite")
    ApiResp<List<ModelCensusFeignVO>> getModelCensusBySiteId(@RequestBody ModelPdu query);




}

@Slf4j
@Component
class ModelFeignFallbackFactory implements FallbackFactory<IApiModelFeign> {

    @Override
    public IApiModelFeign create(Throwable throwable) {
        return new IApiModelFeign() {

            @Override
            public String getSitesByQuery(SitePdu query) {
                ApiResp<String> failResp = new ApiResp<>();
                failResp.setCode(ApiRespCodeEnum.FAILED.getValue());
                failResp.setMsg("暂时无法获取站点列表，请稍后再试!");
                return JSON.toJSONString(failResp);
            }

            @Override
            public ApiResp<List<ModelFeignVO>> getModelByQuery(ModelPdu query) {
                ApiResp<List<ModelFeignVO>> failResp = new ApiResp<>();
                failResp.setCode(ApiRespCodeEnum.FAILED.getValue());
                failResp.setMsg("暂时无法获取站点模块列表，请稍后再试!");
                return failResp;
            }

            @Override
            public ApiResp<List<ModelFeignVO>> getModelBySiteId(ModelPdu query) {
                ApiResp<List<ModelFeignVO>> failResp = new ApiResp<>();
                failResp.setCode(ApiRespCodeEnum.FAILED.getValue());
                failResp.setMsg("暂时无法获取站点模块列表，请稍后再试!");
                return failResp;
            }

            @Override
            public String getModelallInfo(ModelPdu query) {
                ApiResp<String> failResp = new ApiResp<>();
                failResp.setCode(ApiRespCodeEnum.FAILED.getValue());
                failResp.setMsg("暂时无法获取站点模块列表，请稍后再试!");
                return JSON.toJSONString(failResp);
            }

            @Override
            public ApiResp<List<ModelCensusFeignVO>> getModelCensusByQuery(ModelPdu query) {
                ApiResp<List<ModelCensusFeignVO>> failResp = new ApiResp<>();
                failResp.setCode(ApiRespCodeEnum.FAILED.getValue());
                failResp.setMsg("暂时无法获取站点模块数据统计列表，请稍后再试!");
                return failResp;
            }

            @Override
            public ApiResp<List<ModelCensusFeignVO>> getModelCensusBySiteId(ModelPdu query) {
                ApiResp<List<ModelCensusFeignVO>> failResp = new ApiResp<>();
                failResp.setCode(ApiRespCodeEnum.FAILED.getValue());
                failResp.setMsg("暂时无法获取站点模块数据统计列表，请稍后再试!");
                return failResp;
            }

            @Override
            public ApiResp<List<SiteFeignVO>> getSitesAllInfoByQuery(SitePdu query) {
                ApiResp<List<SiteFeignVO>> failResp = new ApiResp<>();
                failResp.setCode(ApiRespCodeEnum.FAILED.getValue());
                failResp.setMsg("暂时无法获取站点模块列表，请稍后再试!");
                return failResp;
            }
        };
    }
}
