package com.mortals.xhx.module.model;

import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.common.Rest;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.web.BaseJsonBodyController;
import com.mortals.xhx.common.code.YesNoEnum;
import com.mortals.xhx.common.pdu.ModelPdu;
import com.mortals.xhx.feign.model.IApiModelFeign;
import com.mortals.xhx.feign.model.vo.ModelCensusFeignVO;
import com.mortals.xhx.feign.model.vo.ModelFeignVO;
import com.mortals.xhx.feign.rsp.ApiResp;
import com.mortals.xhx.module.role.service.RoleModelService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@RestController
@RequestMapping("site/model")
public class ModelController extends BaseJsonBodyController {
    @Autowired
    private IApiModelFeign apiModelFeign;
    @Autowired
    private RoleModelService roleModelService;

    /**
     * 获取所有模块列表
     * @return
     */
    @PostMapping({"list/all"})
    @UnAuth
    public Rest<Object> getAllList() {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        String busiDesc = "查询站点编排" ;
        int code=1;
        try {
            ModelPdu modelPdu = new ModelPdu();
            ApiResp<List<ModelFeignVO>> apiResp = apiModelFeign.getModelByQuery(modelPdu);
            if (apiResp.getCode() != YesNoEnum.YES.getValue()) {
                throw new AppException("获取站点列表信息失败：" + apiResp.getMsg());
            }
            model.put("data", apiResp.getData());
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }
        ret.setCode(code);
        ret.setData(model);
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

    /**
     * 根据站点id查询模块列表
     * @param query
     * @return
     */
    @PostMapping({"list"})
    @UnAuth
    public Rest<Object> getList(@RequestBody ModelVO query) {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        String busiDesc = "查询站点编排" ;
        int code=1;
        try {
            ModelPdu modelPdu = new ModelPdu();
            modelPdu.setSiteId(query.getSiteId());
            ApiResp<List<ModelFeignVO>> apiResp = apiModelFeign.getModelBySiteId(modelPdu);
            if (apiResp.getCode() != YesNoEnum.YES.getValue()) {
                throw new AppException("获取站点列表信息失败：" + apiResp.getMsg());
            }
            if(this.getCurUser()==null){
                throw new AppException("未登录或者登录过期");
            }
            Map<Long,Long> map = roleModelService.getModelIdsUserId(this.getCurUser().getId());
            List<ModelFeignVO> modelFeignVOList = apiResp.getData();
            List<ModelFeignVO> list = modelFeignVOList.stream().filter(item->map.containsKey(item.getId())).collect(Collectors.toList());
            model.put("data", list);
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }
        ret.setCode(code);
        ret.setData(model);
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

    /**
     * 根据站点id查询数据管理列表
     * @param query
     * @return
     */
    @PostMapping({"census/list"})
    @UnAuth
    public Rest<Object> getCensusList(@RequestBody ModelVO query) {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        String busiDesc = "查询站点编排" ;
        int code=1;
        try {
            ModelPdu modelPdu = new ModelPdu();
            modelPdu.setSiteId(query.getSiteId());
            ApiResp<List<ModelCensusFeignVO>> apiResp = apiModelFeign.getModelCensusBySiteId(modelPdu);
            if (apiResp.getCode() != YesNoEnum.YES.getValue()) {
                throw new AppException("获取站点数据管理列表信息失败：" + apiResp.getMsg());
            }
            if(this.getCurUser()==null){
                throw new AppException("未登录或者登录过期");
            }
            Map<Long,Long> map = roleModelService.getModelCensusByUserId(this.getCurUser().getId());
            List<ModelCensusFeignVO> modelFeignVOList = apiResp.getData();
            List<ModelCensusFeignVO> list = modelFeignVOList.stream().filter(item->map.containsKey(item.getId())).collect(Collectors.toList());
            Map<String, List<ModelCensusFeignVO>> resultList = list.stream().collect(Collectors.groupingBy(item->{ return "CensusType_"+item.getCensusType();}));
            model.put("data", resultList);
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }
        ret.setCode(code);
        ret.setData(model);
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

    /**
     * 获取所有数据管理列表
     * @return
     */
    @PostMapping({"census/list/all"})
    @UnAuth
    public Rest<Object> getAllCensusList() {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        String busiDesc = "查询数据管理列表" ;
        int code=1;
        try {
            ModelPdu modelPdu = new ModelPdu();
            ApiResp<List<ModelCensusFeignVO>> apiResp = apiModelFeign.getModelCensusByQuery(modelPdu);
            if (apiResp.getCode() != YesNoEnum.YES.getValue()) {
                throw new AppException("获取所有数据管理列表信息失败：" + apiResp.getMsg());
            }
            model.put("data", apiResp.getData());
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }
        ret.setCode(code);
        ret.setData(model);
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

}
