package com.mortals.xhx.module.role.web;

import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.common.Rest;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.model.PageInfo;
import com.mortals.framework.model.Result;
import com.mortals.framework.util.DataUtil;
import com.mortals.framework.util.StringUtils;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.common.code.YesNoEnum;
import com.mortals.xhx.common.pdu.SitePdu;
import com.mortals.xhx.feign.model.IApiModelFeign;
import com.mortals.xhx.feign.model.vo.SiteFeignVO;
import com.mortals.xhx.feign.rsp.ApiResp;
import com.mortals.xhx.module.role.model.RoleModelEntity;
import com.mortals.xhx.module.role.service.RoleModelService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
*
* 角色模块数据
*
* @author zxfei
* @date 2022-07-05
*/
@RestController
@RequestMapping("role/model")
public class RoleModelController extends BaseCRUDJsonBodyMappingController<RoleModelService,RoleModelEntity,Long> {

    @Autowired
    private IApiModelFeign apiModelFeign;

    public RoleModelController(){
        super.setModuleDesc( "角色模块数据");
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
        super.init(model, context);
    }


    @PostMapping({"site/allInfo"})
    @UnAuth
    public Rest<Object> list(@RequestBody RoleModelEntity query) {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        String busiDesc = "查询登录用户具有的站点信息";
        int code=1;
        try {
            String siteIds = this.getCurUser().getSiteIds();
            List<String> siteIdList = StringUtils.converStr2List(siteIds);
            List<Long> ids = siteIdList.stream().map(s -> DataUtil.converStr2Long(s.trim(),0)).collect(Collectors.toList());
            SitePdu sitePdu =new SitePdu();
            sitePdu.setIdList(ids);
            ApiResp<List<SiteFeignVO>> apiResp = apiModelFeign.getSitesAllInfoByQuery(sitePdu);
            if (apiResp.getCode() != YesNoEnum.YES.getValue()) {
                throw new AppException("获取站点列表信息失败：" + apiResp.getMsg());
            }
            model.put("data", apiResp.getData());
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }
        ret.setCode(code);
        ret.setData(model);
        ret.setDict(model.get("dict"));
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }
}